From: Alasdair G Kergon <[email-masked]>

Fix up to use queue_max_hw_sectors() for linux-next.

Signed-off-by: Alasdair G Kergon <[email-masked]>
---
 drivers/md/dm.c |    5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

Index: linux-2.6.30/drivers/md/dm.c
===================================================================
--- linux-2.6.30.orig/drivers/md/dm.c
+++ linux-2.6.30/drivers/md/dm.c
@@ -928,11 +928,12 @@ static int dm_merge_bvec(struct request_
 	/*
 	 * If the target doesn't support merge method and some of the devices
 	 * provided their merge_bvec method (we know this by looking at
 	 * max_hw_sectors), then we can't allow bios with multiple vector
 	 * entries.  So always set max_size to 0, and the code below allows
 	 * just one page.
 	 */
-	else if (q->max_hw_sectors <= PAGE_SIZE >> 9)
+	else if (queue_max_hw_sectors(q) <= PAGE_SIZE >> 9)
+
 		max_size = 0;
 
 out_table:
@@ -928,11 +928,12 @@ static int dm_merge_bvec(struct request_
 	 * If the target doesn't support merge method and some of the devices
 	 * provided their merge_bvec method (we know this by looking at
-	 * max_hw_sectors), then we can't allow bios with multiple vector
+	 * queue_max_hw_sectors), then we can't allow bios with multiple vector
 	 * entries.  So always set max_size to 0, and the code below allows
 	 * just one page.